# Python VHS

[VHS] is a tool by [charm] that renders terminal commands into GIFs.
This is a python package that includes VHS binary with all its dependencies,
and a simple API to run those.

[VHS]: https://github.com/charmbracelet/vhs
[charm]: https://charm.sh/

## Resources

- [Documentation](https://python-vhs.readthedocs.io/en/stable/)
- [Issues](https://github.com/taminomara/python-vhs/issues)
- [Source](https://github.com/taminomara/python-vhs/)
- [PyPi](https://pypi.org/project/vhs/)
- [Changelog](https://github.com/taminomara/python-vhs/blob/main/CHANGELOG.md)
